@@ -33,6 +33,11 @@ st_as_grob.LINESTRING = function(x, ..., default.units = "native") {
 		linesGrob(x[,1], x[,2], ..., default.units = default.units)
 }
 
+#' @export
+st_as_grob.CIRCULARSTRING = function(x, y, ...) {
+	st_as_grob(st_cast(x, "LINESTRING"),  ...)
+}
+
 #' @export
 st_as_grob.MULTILINESTRING = function(x, ..., default.units = "native") {
 	if (length(x) == 0)
@@ -76,6 +81,15 @@ st_as_grob.GEOMETRYCOLLECTION = function(x, ..., default.units = "native") {
 		do.call(grid::grobTree, lapply(x, st_as_grob, ..., default.units = default.units))
 }
 
+#' @export
+st_as_grob.MULTISURFACE = st_as_grob.GEOMETRYCOLLECTION
+
+#' @export
+st_as_grob.CURVEPOLYGON = st_as_grob.GEOMETRYCOLLECTION
+
+#' @export
+st_as_grob.COMPOUNDCURVE = st_as_grob.GEOMETRYCOLLECTION
+
 
 #' Create viewport from sf, sfc or sfg object
 #' 
