@@ -129,8 +129,11 @@ st_multipoint = function(x = matrix(numeric(0), 0, 2), dim = "XYZ") Mtrx(x, dim,
 st_linestring = function(x = matrix(numeric(0), 0, 2), dim = "XYZ") Mtrx(x, dim, type = "LINESTRING")
 #' @name st
 #' @export
-st_polygon = function(x = list(), dim = if(length(x)) "XYZ" else "XY")
-	MtrxSet(x, dim, type = "POLYGON", needClosed = TRUE)
+st_polygon = function(x = list(), dim = if(length(x)) "XYZ" else "XY") {
+	if (identical(x, 1))
+		st_polygon(list(rbind(c(0,0),c(1,0),c(1,1),c(0,1),c(0,0))))
+	else MtrxSet(x, dim, type = "POLYGON", needClosed = TRUE)
+}
 #' @name st
 #' @export
 st_multilinestring = function(x = list(), dim = if (length(x)) "XYZ" else "XY")
