@@ -117,3 +117,17 @@ if (version$os == "linux-gnu") { # why does this break on windows - degree symbo
 }
 x = st_transform(sfc, 3857)
 st_buffer(x, units::set_units(1000, km)) # success
+
+cr = st_as_sfc("CIRCULARSTRING(0 0,1 0,1 1)")
+cr1 = st_sf(a = 1, geometry = cr)
+plot(cr)
+st_as_grob(cr[[1]])
+
+x = st_as_sfc("MULTISURFACE(CURVEPOLYGON(COMPOUNDCURVE(LINESTRING(-159.399779123 22.226016471, -159.399699153 22.226276431, -159.398736217 22.226118372, -159.398260872 22.226095318, -159.398140792 22.2260564590001, -159.398163058 22.2257268010001, -159.397882642 22.225394244, -159.397397157 22.225057335, -159.397318825 22.2251780230001, -159.396993115 22.225177984, -159.396748242 22.2248808800001, -159.396901679 22.224770398, -159.396876329 22.224673093, -159.399167008 22.224731392, -159.399502204 22.225551382), CIRCULARSTRING(-159.399502204 22.225551382, -159.399622762077 22.2257930044972, -159.399779123 22.226016471))))")
+mp <- x[[1]] %>% st_cast("MULTIPOLYGON")
+
+x = st_as_sfc("COMPOUNDCURVE(CIRCULARSTRING(0 0, 1 1, 1 0),(1 0, 0 1))")
+ls <- x[[1]] %>% st_cast()
+class(ls)
+
+is.na(st_bbox(ls))
